#
# spec file for package clash-ghc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name clash-ghc
Name:           %{pkg_name}
Version:        0.99.2
Release:        1.2
Summary:        CAES Language for Synchronous Hardware
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-bifunctors-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-clash-lib-devel
BuildRequires:  ghc-clash-prelude-devel
BuildRequires:  ghc-concurrent-supply-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-ghc-boot-devel
BuildRequires:  ghc-ghc-devel
BuildRequires:  ghc-ghc-typelits-extra-devel
BuildRequires:  ghc-ghc-typelits-knownnat-devel
BuildRequires:  ghc-ghc-typelits-natnormalise-devel
BuildRequires:  ghc-ghci-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-haskeline-devel
BuildRequires:  ghc-lens-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-reflection-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unbound-generics-devel
BuildRequires:  ghc-uniplate-devel
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  glibc-devel

%description
CλaSH (pronounced ‘clash’) is a functional hardware description language that
borrows both its syntax and semantics from the functional programming language
Haskell. The CλaSH compiler transforms these high-level descriptions to
low-level synthesizable VHDL, Verilog, or SystemVerilog.

Features of CλaSH:

* Strongly typed, but with a very high degree of type inference, enabling both
safe and fast prototyping using concise descriptions.

* Interactive REPL: load your designs in an interpreter and easily test all
your component without needing to setup a test bench.

* Higher-order functions, with type inference, result in designs that are fully
parametric by default.

* Synchronous sequential circuit design based on streams of values, called
'Signal's, lead to natural descriptions of feedback loops.

* Support for multiple clock domains, with type safe clock domain crossing.

This package provides:

* CλaSH Compiler binary using GHC/Haskell as a frontend

Prelude library: <http://hackage.haskell.org/package/clash-prelude>.

%package -n ghc-%{name}
Summary:        Haskell %{name} library
Group:          System/Libraries

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.

%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Group:          Development/Libraries/Haskell
Requires:       ghc-%{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires:       glibc-devel
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.

%prep
%setup -q
sed -i -e 's/-dynamic//' clash-ghc.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%post -n ghc-%{name}-devel
%ghc_pkg_recache

%postun -n ghc-%{name}-devel
%ghc_pkg_recache

%files
%license LICENSE
%doc CHANGELOG.md LICENSE_GHC README.md
%{_bindir}/clash
%{_bindir}/clashi

%files -n ghc-%{name} -f ghc-%{name}.files
%license LICENSE

%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%doc CHANGELOG.md LICENSE_GHC README.md

%changelog
* Mon Jul  9 2018 psimons@suse.com
- Update clash-ghc to version 0.99.2.
  [#] Changelog for the [`clash-ghc`](http://hackage.haskell.org/package/clash-ghc) package
  [#]# 0.99.1 *May 12th 2018*
  * Allow `~NAME[N]` tag inside `~GENSYM[X]`
  * Support HDL record selector generation [#313](https://github.com/clash-lang/clash-compiler/pull/313)
* Thu Apr  5 2018 psimons@suse.com
- Update clash-ghc to version 0.99.
  A more detailed change log is not available.
